@@ -1,6 +1,6 @@
 package IP::CountryFlag::UserAgent::Exception;
 
-$IP::CountryFlag::Exception::VERSION   = '0.07';
+$IP::CountryFlag::Exception::VERSION   = '0.08';
 $IP::CountryFlag::Exception::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ IP::CountryFlag::UserAgent::Exception - Exception handler for the module IP::Cou
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -43,7 +43,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/IP-CountryFlag>
+L<https://github.com/manwar/IP-CountryFlag>
 
 =head1 BUGS
 
@@ -82,7 +82,7 @@ L<http://search.cpan.org/dist/IP-CountryFlag/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2011 - 2015 Mohammad S Anwar.
+Copyright (C) 2011 - 2016 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it and/or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
